@@ -20,8 +20,7 @@ from datetime import datetime
 from typing import List
 
 import requests
-
-from tencentcloud_im.user_sig import TLSSigAPIv2
+from TLSSigAPIv2 import TLSSigAPIv2
 
 TCIM_API_BASE = "https://console.tim.qq.com/v4"
 
@@ -163,7 +162,7 @@ class TCIMClient(object):
     :return:
     """
     api = TLSSigAPIv2(self.sdk_id, self.key)
-    sig = api.genUserSig(user_id, expire_time)
+    sig = api.gen_sig(user_id, expire_time)
     return sig
 
   def _gen_query(self):
@@ -221,11 +220,11 @@ class TCIMClient(object):
       return
 
     try:
-      rest_url = "{}/v4/im_open_login_svc/multiaccount_import".format(self.tecent_url)
-      data = {}
-      data["Accounts"] = user_ids
-      query = self._gen_query()
-      return requests.post(rest_url, params=query, data=json.dumps(data))
+        rest_url = "{}/im_open_login_svc/multiaccount_import".format(self.tecent_url)
+        data = {}
+        data["Accounts"] = user_ids
+        query = self._gen_query()
+        return requests.post(rest_url, params=query, data=json.dumps(data))
     except Exception as e:
       logger.error("batch add user failed:{}".format(e))
       return None
@@ -341,7 +340,7 @@ class TCIMClient(object):
     :param delete_type: 删除类型：Delete_Type_Both：双向删除， Delete_Type_Single:单向删除
     :return:
     """
-    rest_url = "{}/v4/sns/friend_delete".format(self.tecent_url)
+    rest_url = "{}/sns/friend_delete".format(self.tecent_url)
     data = {}
     try:
       data["From_Account"] = from_account
@@ -360,7 +359,7 @@ class TCIMClient(object):
     :return:
     """
 
-    rest_url = "{}/v4/sns/friend_update".format(self.tecent_url)
+    rest_url = "{}/sns/friend_update".format(self.tecent_url)
     data = {}
     try:
       updateItems = []
@@ -382,7 +381,7 @@ class TCIMClient(object):
     :return:
     """
 
-    rest_url = "{}/v4/sns/friend_get".format(self.tecent_url)
+    rest_url = "{}/sns/friend_get".format(self.tecent_url)
     data = {}
     try:
       data["From_Account"] = from_account
@@ -402,7 +401,7 @@ class TCIMClient(object):
     :return:
     """
 
-    rest_url = "{}/v4/sns/group_add".format(self.tecent_url)
+    rest_url = "{}/sns/group_add".format(self.tecent_url)
     data = {}
     try:
       data["From_Account"] = from_account
@@ -423,12 +422,13 @@ class TCIMClient(object):
     """
 
     try:
-      rest_url = "{}/v4/sns/group_delete".format(self.tecent_url)
-      data = {}
-      data["From_Account"] = from_account
-      data["GroupName"] = groups
-      query = self._gen_query()
-      return requests.post(rest_url, params=query, data=json.dumps(data))
+        rest_url = "{}/sns/group_delete".format(self.tecent_url)
+        data = {}
+        data["From_Account"] = from_account
+        data["GroupName"] = groups
+        query = self._gen_query()
+        return requests.post(rest_url, params=query, data=json.dumps(data))
+
     except Exception as e:
       logger.error("delete group failed:{}".format(e))
       return None
@@ -447,7 +447,7 @@ class TCIMClient(object):
     :return:
     """
 
-    rest_url = "{}/v4/sns/group_get".format(self.tecent_url)
+    rest_url = "{}/sns/group_get".format(self.tecent_url)
     data = {}
     try:
       data["From_Account"] = from_account
@@ -462,4 +462,4 @@ class TCIMClient(object):
 
 
 if __name__ == "__main__":
-  pass
+    pass
